LDAP – lightweight directory access) — summer 0.7.8 documentation

# LDAP – lightweight directory access)

## lsf – LDAP session factory

Module `lsf` defines `LdapSessionFactory` class which is central point for your LDAP database access.

Analogy to `summer.sf`.

## ldapdao – LDAP data access object support

Provides LDAP DAO support. Analogy to `summer.dao` module.

Base `LdapDao` provides access to important properties:

1. `LdapDao.connection()` property referencing `ldap3.Connection`

2. `LdapDao.base()` property referencing `summer.lsf.LdapSessionFactory.base` dn value (useful for creating LDAP queries)